@@ -16,7 +16,11 @@ def marc8_to_unicode(marc8, hide_utf8_warnings=False):
     # XXX: might be good to stash away a converter somehow
     # instead of always re-creating it 
     converter = MARC8ToUnicode(quiet=hide_utf8_warnings)
-    return converter.translate(marc8)
+    try: 
+        return converter.translate(marc8)
+    except IndexError, ie:
+        # convert IndexError into UnicodeDecodeErrors
+        raise UnicodeDecodeError("marc8_to_unicode", marc8, 0, len(marc8), "invalid multibyte character encoding")
 
 
 class MARC8ToUnicode:
